
from setuptools import setup, find_packages

setup(
    name='entrypoints',
    version='0.3',
    description='Discover and load entry points from installed packages',
    url='https://github.com/takluyver/entrypoints',
    author='https://github.com/takluyver',
    license='MIT',
    long_description='The entrypoints module contains functions to find and load entry points, a way for Python packages to advertise objects.',
    py_modules=['entrypoints']
)
